CVS commit: src/external/bsd/atf/dist

2015-01-22 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Thu Jan 22 12:33:36 UTC 2015

Modified Files:
src/external/bsd/atf/dist/atf-c: macros_test.c
src/external/bsd/atf/dist/atf-c++: macros_test.cpp

Log Message:
Mark atf/atf-c/macros_test/detect_unused_tests and
atf/atf-c++/macros_test/detect_unused_tests as expected failures
when using versions of GCC where they are known to fail, with a
reference to PR toolchain/49187.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/external/bsd/atf/dist/atf-c/macros_test.c
cvs rdiff -u -r1.1.1.8 -r1.2 \
src/external/bsd/atf/dist/atf-c++/macros_test.cpp

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/atf/dist/atf-c/macros_test.c
diff -u src/external/bsd/atf/dist/atf-c/macros_test.c:1.4 src/external/bsd/atf/dist/atf-c/macros_test.c:1.5
--- src/external/bsd/atf/dist/atf-c/macros_test.c:1.4	Sat Feb  8 19:13:43 2014
+++ src/external/bsd/atf/dist/atf-c/macros_test.c	Thu Jan 22 12:33:35 2015
@@ -863,6 +863,10 @@ ATF_TC_BODY(detect_unused_tests, tc)
 atf_tc_expect_fail(Compiler does not raise a warning on an unused 
static global variable declared by a macro);
 
+#if __GNUC__  4 || (__GNUC__ == 4  __GNUC_MINOR__ = 8)
+atf_tc_expect_fail(PR 49187);
+#endif
+
 if (build_check_c_o_srcdir(tc, unused_test.c))
 atf_tc_fail(Build of unused_test.c passed; unused test cases are 
 not properly detected);

Index: src/external/bsd/atf/dist/atf-c++/macros_test.cpp
diff -u src/external/bsd/atf/dist/atf-c++/macros_test.cpp:1.1.1.8 src/external/bsd/atf/dist/atf-c++/macros_test.cpp:1.2
--- src/external/bsd/atf/dist/atf-c++/macros_test.cpp:1.1.1.8	Sat Feb  8 19:11:31 2014
+++ src/external/bsd/atf/dist/atf-c++/macros_test.cpp	Thu Jan 22 12:33:36 2015
@@ -783,6 +783,10 @@ ATF_TEST_CASE_BODY(detect_unused_tests)
 expect_fail(Compiler does not raise a warning on an unused 
 static global variable declared by a macro);
 
+#if __GNUC__  4 || (__GNUC__ == 4  __GNUC_MINOR__ = 8)
+expect_fail(PR 49187);
+#endif
+
 if (build_check_cxx_o_srcdir(*this, unused_test.cpp))
 ATF_FAIL(Build of unused_test.cpp passed; unused test cases are 
  not properly detected);



CVS commit: src/external/bsd/atf/dist

2015-01-22 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Thu Jan 22 12:33:36 UTC 2015

Modified Files:
src/external/bsd/atf/dist/atf-c: macros_test.c
src/external/bsd/atf/dist/atf-c++: macros_test.cpp

Log Message:
Mark atf/atf-c/macros_test/detect_unused_tests and
atf/atf-c++/macros_test/detect_unused_tests as expected failures
when using versions of GCC where they are known to fail, with a
reference to PR toolchain/49187.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/external/bsd/atf/dist/atf-c/macros_test.c
cvs rdiff -u -r1.1.1.8 -r1.2 \
src/external/bsd/atf/dist/atf-c++/macros_test.cpp

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/external/gpl3/gcc/dist/gcc/config/rs6000

2015-01-22 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Thu Jan 22 08:35:05 UTC 2015

Modified Files:
src/external/gpl3/gcc/dist/gcc/config/rs6000: netbsd.h

Log Message:
Make sure POWERPC_NETBSD is defined.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 \
src/external/gpl3/gcc/dist/gcc/config/rs6000/netbsd.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/external/gpl3/gcc/dist/gcc/config/rs6000

2015-01-22 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Thu Jan 22 08:35:05 UTC 2015

Modified Files:
src/external/gpl3/gcc/dist/gcc/config/rs6000: netbsd.h

Log Message:
Make sure POWERPC_NETBSD is defined.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 \
src/external/gpl3/gcc/dist/gcc/config/rs6000/netbsd.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/gpl3/gcc/dist/gcc/config/rs6000/netbsd.h
diff -u src/external/gpl3/gcc/dist/gcc/config/rs6000/netbsd.h:1.7 src/external/gpl3/gcc/dist/gcc/config/rs6000/netbsd.h:1.8
--- src/external/gpl3/gcc/dist/gcc/config/rs6000/netbsd.h:1.7	Sat Aug 23 02:17:47 2014
+++ src/external/gpl3/gcc/dist/gcc/config/rs6000/netbsd.h	Thu Jan 22 08:35:05 2015
@@ -118,6 +118,7 @@
 #define TARGET_SECURE_PLT secure_plt
 #undef HAVE_AS_TLS
 #define HAVE_AS_TLS 1
+#define POWERPC_NETBSD
 
 /* Attempt to enable execute permissions on the stack.  */
 //#define TRANSFER_FROM_TRAMPOLINE NETBSD_ENABLE_EXECUTE_STACK



CVS commit: src/lib/libutil

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 22 16:19:08 UTC 2015

Modified Files:
src/lib/libutil: pidfile.c

Log Message:
- not all asprintfs return -1 *and* set buf = NULL, check explicitly.
- don't shadow basename(3)


To generate a diff of this commit:
cvs rdiff -u -r1.9 -r1.10 src/lib/libutil/pidfile.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libutil/pidfile.c
diff -u src/lib/libutil/pidfile.c:1.9 src/lib/libutil/pidfile.c:1.10
--- src/lib/libutil/pidfile.c:1.9	Tue Mar 29 09:55:37 2011
+++ src/lib/libutil/pidfile.c	Thu Jan 22 11:19:08 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: pidfile.c,v 1.9 2011/03/29 13:55:37 jmmv Exp $	*/
+/*	$NetBSD: pidfile.c,v 1.10 2015/01/22 16:19:08 christos Exp $	*/
 
 /*-
  * Copyright (c) 1999 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
 
 #include sys/cdefs.h
 #if defined(LIBC_SCCS)  !defined(lint)
-__RCSID($NetBSD: pidfile.c,v 1.9 2011/03/29 13:55:37 jmmv Exp $);
+__RCSID($NetBSD: pidfile.c,v 1.10 2015/01/22 16:19:08 christos Exp $);
 #endif
 
 #include sys/param.h
@@ -105,15 +105,16 @@ cleanup_old_pidfile(const char* path)
  * Returns a pointer to a dynamically-allocatd string containing the absolute
  * path to the pidfile; NULL on failure. */
 static char *
-generate_varrun_path(const char *basename)
+generate_varrun_path(const char *bname)
 {
 	char *path;
 
-	if (basename == NULL)
-		basename = getprogname();
+	if (bname == NULL)
+		bname = getprogname();
 
 	/* _PATH_VARRUN includes trailing / */
-	(void) asprintf(path, %s%s.pid, _PATH_VARRUN, basename);
+	if (asprintf(path, %s%s.pid, _PATH_VARRUN, basename) == -1)
+		return NULL;
 	return path;
 }
 



CVS commit: src/lib/libutil

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 22 16:19:08 UTC 2015

Modified Files:
src/lib/libutil: pidfile.c

Log Message:
- not all asprintfs return -1 *and* set buf = NULL, check explicitly.
- don't shadow basename(3)


To generate a diff of this commit:
cvs rdiff -u -r1.9 -r1.10 src/lib/libutil/pidfile.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/usr.sbin/mtree

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 02:27:01 UTC 2015

Modified Files:
src/usr.sbin/mtree: mtree.8 mtree.c verify.c

Log Message:
attempt to reset file flags when -rr


To generate a diff of this commit:
cvs rdiff -u -r1.69 -r1.70 src/usr.sbin/mtree/mtree.8
cvs rdiff -u -r1.49 -r1.50 src/usr.sbin/mtree/mtree.c
cvs rdiff -u -r1.44 -r1.45 src/usr.sbin/mtree/verify.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.sbin/mtree/mtree.8
diff -u src/usr.sbin/mtree/mtree.8:1.69 src/usr.sbin/mtree/mtree.8:1.70
--- src/usr.sbin/mtree/mtree.8:1.69	Sun Feb  3 14:16:06 2013
+++ src/usr.sbin/mtree/mtree.8	Thu Jan 22 21:27:01 2015
@@ -1,4 +1,4 @@
-.\	$NetBSD: mtree.8,v 1.69 2013/02/03 19:16:06 christos Exp $
+.\	$NetBSD: mtree.8,v 1.70 2015/01/23 02:27:01 christos Exp $
 .\
 .\ Copyright (c) 1989, 1990, 1993
 .\	The Regents of the University of California.  All rights reserved.
@@ -56,7 +56,7 @@
 .\
 .\ @(#)mtree.8	8.2 (Berkeley) 12/11/93
 .\
-.Dd February 3, 2013
+.Dd January 22, 2014
 .Dt MTREE 8
 .Os
 .Sh NAME
@@ -299,6 +299,10 @@ is specified, remove all of the other ke
 .It Fl r
 Remove any files in the file hierarchy that are not described in the
 specification.
+Repeating the flag more than once will attempt to reset all the
+file flags via
+.Xr lchflags 2
+before attempting to remove the file in case the file was immutable.
 .It Fl S
 When reading a specification into an internal data structure,
 sort the entries.

Index: src/usr.sbin/mtree/mtree.c
diff -u src/usr.sbin/mtree/mtree.c:1.49 src/usr.sbin/mtree/mtree.c:1.50
--- src/usr.sbin/mtree/mtree.c:1.49	Thu Apr 24 13:22:41 2014
+++ src/usr.sbin/mtree/mtree.c	Thu Jan 22 21:27:01 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: mtree.c,v 1.49 2014/04/24 17:22:41 christos Exp $	*/
+/*	$NetBSD: mtree.c,v 1.50 2015/01/23 02:27:01 christos Exp $	*/
 
 /*-
  * Copyright (c) 1989, 1990, 1993
@@ -43,7 +43,7 @@ __COPYRIGHT(@(#) Copyright (c) 1989, 19
 #if 0
 static char sccsid[] = @(#)mtree.c	8.1 (Berkeley) 6/6/93;
 #else
-__RCSID($NetBSD: mtree.c,v 1.49 2014/04/24 17:22:41 christos Exp $);
+__RCSID($NetBSD: mtree.c,v 1.50 2015/01/23 02:27:01 christos Exp $);
 #endif
 #endif /* not lint */
 
@@ -195,7 +195,7 @@ main(int argc, char **argv)
 			qflag = 1;
 			break;
 		case 'r':
-			rflag = 1;
+			rflag++;
 			break;
 		case 'R':
 			while ((p = strsep(optarg,  \t,)) != NULL)

Index: src/usr.sbin/mtree/verify.c
diff -u src/usr.sbin/mtree/verify.c:1.44 src/usr.sbin/mtree/verify.c:1.45
--- src/usr.sbin/mtree/verify.c:1.44	Sun Feb  3 14:15:17 2013
+++ src/usr.sbin/mtree/verify.c	Thu Jan 22 21:27:01 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: verify.c,v 1.44 2013/02/03 19:15:17 christos Exp $	*/
+/*	$NetBSD: verify.c,v 1.45 2015/01/23 02:27:01 christos Exp $	*/
 
 /*-
  * Copyright (c) 1990, 1993
@@ -38,7 +38,7 @@
 #if 0
 static char sccsid[] = @(#)verify.c	8.1 (Berkeley) 6/6/93;
 #else
-__RCSID($NetBSD: verify.c,v 1.44 2013/02/03 19:15:17 christos Exp $);
+__RCSID($NetBSD: verify.c,v 1.45 2015/01/23 02:27:01 christos Exp $);
 #endif
 #endif /* not lint */
 
@@ -149,6 +149,10 @@ vwalk(void)
 		if (!eflag  !(dflag  p-fts_info == FTS_SL)) {
 			printf(extra: %s, RP(p));
 			if (rflag) {
+if (rflag  1 
+lchflags(p-fts_accpath, 0) == -1)
+	printf( (chflags %s),
+	strerror(errno));
 if ((S_ISDIR(p-fts_statp-st_mode)
 ? rmdir : unlink)(p-fts_accpath)) {
 	printf(, not removed: %s,



CVS commit: src/usr.sbin/mtree

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 02:27:01 UTC 2015

Modified Files:
src/usr.sbin/mtree: mtree.8 mtree.c verify.c

Log Message:
attempt to reset file flags when -rr


To generate a diff of this commit:
cvs rdiff -u -r1.69 -r1.70 src/usr.sbin/mtree/mtree.8
cvs rdiff -u -r1.49 -r1.50 src/usr.sbin/mtree/mtree.c
cvs rdiff -u -r1.44 -r1.45 src/usr.sbin/mtree/verify.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/fs/msdosfs

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 02:39:48 UTC 2015

Modified Files:
src/sys/fs/msdosfs: msdosfs_vfsops.c

Log Message:
add some more paranoid checks about secsize and struct use.


To generate a diff of this commit:
cvs rdiff -u -r1.115 -r1.116 src/sys/fs/msdosfs/msdosfs_vfsops.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/fs/msdosfs/msdosfs_vfsops.c
diff -u src/sys/fs/msdosfs/msdosfs_vfsops.c:1.115 src/sys/fs/msdosfs/msdosfs_vfsops.c:1.116
--- src/sys/fs/msdosfs/msdosfs_vfsops.c:1.115	Fri Jul 18 13:24:34 2014
+++ src/sys/fs/msdosfs/msdosfs_vfsops.c	Thu Jan 22 21:39:48 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: msdosfs_vfsops.c,v 1.115 2014/07/18 17:24:34 maxv Exp $	*/
+/*	$NetBSD: msdosfs_vfsops.c,v 1.116 2015/01/23 02:39:48 christos Exp $	*/
 
 /*-
  * Copyright (C) 1994, 1995, 1997 Wolfgang Solfrank.
@@ -48,7 +48,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: msdosfs_vfsops.c,v 1.115 2014/07/18 17:24:34 maxv Exp $);
+__KERNEL_RCSID(0, $NetBSD: msdosfs_vfsops.c,v 1.116 2015/01/23 02:39:48 christos Exp $);
 
 #if defined(_KERNEL_OPT)
 #include opt_compat_netbsd.h
@@ -510,6 +510,11 @@ msdosfs_mountfs(struct vnode *devvp, str
 	 * Read the boot sector of the filesystem, and then check the
 	 * boot signature.  If not a dos boot sector then error out.
 	 */
+	if (secsize  sizeof(*b50)) {
+		DPRINTF((50 bootsec %u\n, secsize));
+		error = EINVAL;
+		goto error_exit;
+	}
 	if ((error = bread(devvp, 0, secsize, NOCRED, 0, bp)) != 0)
 		goto error_exit;
 	bsp = (union bootsector *)bp-b_data;
@@ -551,6 +556,11 @@ msdosfs_mountfs(struct vnode *devvp, str
 		pmp-pm_HiddenSects = getulong(b50-bpbHiddenSecs);
 		pmp-pm_HugeSectors = getulong(b50-bpbHugeSectors);
 	} else {
+		if (secsize  sizeof(*b33)) {
+			DPRINTF((33 bootsec %u\n, secsize));
+			error = EINVAL;
+			goto error_exit;
+		}
 		pmp-pm_HiddenSects = getushort(b33-bpbHiddenSecs);
 		pmp-pm_HugeSectors = pmp-pm_Sectors;
 	}
@@ -579,6 +589,11 @@ msdosfs_mountfs(struct vnode *devvp, str
 	}
 
 	if (pmp-pm_RootDirEnts == 0) {
+		if (secsize  sizeof(*b710)) {
+			DPRINTF((710 bootsec %u\n, secsize));
+			error = EINVAL;
+			goto error_exit;
+		}
 		unsigned short FSVers = getushort(b710-bpbFSVers);
 		unsigned short ExtFlags = getushort(b710-bpbExtFlags);
 		/*
@@ -650,6 +665,11 @@ msdosfs_mountfs(struct vnode *devvp, str
 
 	pmp-pm_fatblk = pmp-pm_ResSectors;
 	if (FAT32(pmp)) {
+		if (secsize  sizeof(*b710)) {
+			DPRINTF((710 bootsec %u\n, secsize));
+			error = EINVAL;
+			goto error_exit;
+		}
 		pmp-pm_rootdirblk = getulong(b710-bpbRootClust);
 		pmp-pm_firstcluster = pmp-pm_fatblk
 			+ (pmp-pm_FATs * pmp-pm_FATsecs);



CVS commit: src/sys/fs/msdosfs

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 02:39:48 UTC 2015

Modified Files:
src/sys/fs/msdosfs: msdosfs_vfsops.c

Log Message:
add some more paranoid checks about secsize and struct use.


To generate a diff of this commit:
cvs rdiff -u -r1.115 -r1.116 src/sys/fs/msdosfs/msdosfs_vfsops.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/i386/i386

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 02:52:14 UTC 2015

Modified Files:
src/sys/arch/i386/i386: machdep.c

Log Message:
whitespace


To generate a diff of this commit:
cvs rdiff -u -r1.752 -r1.753 src/sys/arch/i386/i386/machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/i386/i386/machdep.c
diff -u src/sys/arch/i386/i386/machdep.c:1.752 src/sys/arch/i386/i386/machdep.c:1.753
--- src/sys/arch/i386/i386/machdep.c:1.752	Sun Feb 23 17:36:43 2014
+++ src/sys/arch/i386/i386/machdep.c	Thu Jan 22 21:52:14 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: machdep.c,v 1.752 2014/02/23 22:36:43 dsl Exp $	*/
+/*	$NetBSD: machdep.c,v 1.753 2015/01/23 02:52:14 christos Exp $	*/
 
 /*-
  * Copyright (c) 1996, 1997, 1998, 2000, 2004, 2006, 2008, 2009
@@ -67,7 +67,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: machdep.c,v 1.752 2014/02/23 22:36:43 dsl Exp $);
+__KERNEL_RCSID(0, $NetBSD: machdep.c,v 1.753 2015/01/23 02:52:14 christos Exp $);
 
 #include opt_beep.h
 #include opt_compat_ibcs2.h
@@ -936,7 +936,8 @@ int xen_idt_idx;
 extern union descriptor tmpgdt[];
 #endif
 
-void cpu_init_idt(void)
+void 
+cpu_init_idt(void)
 {
 #ifndef XEN
 	struct region_descriptor region;



CVS commit: src/external/bsd/wpa/bin/hostapd

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 02:57:34 UTC 2015

Modified Files:
src/external/bsd/wpa/bin/hostapd: Makefile

Log Message:
move crypto file to the right group


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 src/external/bsd/wpa/bin/hostapd/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/wpa/bin/hostapd/Makefile
diff -u src/external/bsd/wpa/bin/hostapd/Makefile:1.6 src/external/bsd/wpa/bin/hostapd/Makefile:1.7
--- src/external/bsd/wpa/bin/hostapd/Makefile:1.6	Thu Oct 16 15:29:29 2014
+++ src/external/bsd/wpa/bin/hostapd/Makefile	Thu Jan 22 21:57:34 2015
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.6 2014/10/16 19:29:29 christos Exp $
+# $NetBSD: Makefile,v 1.7 2015/01/23 02:57:34 christos Exp $
 
 .include ${.CURDIR}/../Makefile.inc
 
@@ -84,6 +84,7 @@ eap_server_methods.c
 
 # crypto
 SRCS+= \
+crypto_openssl.c \
 md5.c \
 random.c \
 sha1-prf.c
@@ -144,7 +145,6 @@ aes-eax.c \
 aes-encblock.c \
 aes-omac1.c \
 aes-wrap.c \
-crypto_openssl.c \
 dh_groups.c \
 fips_prf_openssl.c \
 ms_funcs.c \



CVS commit: src/external/bsd/wpa/bin/hostapd

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 02:57:34 UTC 2015

Modified Files:
src/external/bsd/wpa/bin/hostapd: Makefile

Log Message:
move crypto file to the right group


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 src/external/bsd/wpa/bin/hostapd/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/external/bsd/top/dist

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 02:58:40 UTC 2015

Modified Files:
src/external/bsd/top/dist: top.1.in

Log Message:
use more markup


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 src/external/bsd/top/dist/top.1.in

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/top/dist/top.1.in
diff -u src/external/bsd/top/dist/top.1.in:1.6 src/external/bsd/top/dist/top.1.in:1.7
--- src/external/bsd/top/dist/top.1.in:1.6	Wed Mar 20 21:39:04 2013
+++ src/external/bsd/top/dist/top.1.in	Thu Jan 22 21:58:40 2015
@@ -166,7 +166,9 @@ Only display the specified pid.
 .B \-s \fItime\fP, \-\-delay=\fItime\fP
 Set the delay between screen updates to
 .I time
-seconds.  The default delay between updates is \nD seconds.
+seconds.  The default delay between updates is
+.af D 1 
+seconds.
 .TP
 .B \-U \fIusername\fP, \-\-user=\fIusername\fP
 Show only those processes owned by



CVS commit: src/external/bsd/top/dist

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 02:58:40 UTC 2015

Modified Files:
src/external/bsd/top/dist: top.1.in

Log Message:
use more markup


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 src/external/bsd/top/dist/top.1.in

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/external/bsd/dhcp

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 03:00:44 UTC 2015

Modified Files:
src/external/bsd/dhcp: Makefile.inc

Log Message:
turn back to dynamic to reduce size.


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.13 src/external/bsd/dhcp/Makefile.inc

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/external/bsd/dhcp

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 03:00:44 UTC 2015

Modified Files:
src/external/bsd/dhcp: Makefile.inc

Log Message:
turn back to dynamic to reduce size.


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.13 src/external/bsd/dhcp/Makefile.inc

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/dhcp/Makefile.inc
diff -u src/external/bsd/dhcp/Makefile.inc:1.12 src/external/bsd/dhcp/Makefile.inc:1.13
--- src/external/bsd/dhcp/Makefile.inc:1.12	Fri Sep 26 18:18:48 2014
+++ src/external/bsd/dhcp/Makefile.inc	Thu Jan 22 22:00:44 2015
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile.inc,v 1.12 2014/09/26 22:18:48 christos Exp $
+# $NetBSD: Makefile.inc,v 1.13 2015/01/23 03:00:44 christos Exp $
 
 WARNS?=	1	# XXX -Wshadow -Wcast-qual -Wsign-compare
 
@@ -49,6 +49,9 @@ LDADD+=-Wl,-Bdynamic
 LDADD+= -lcrypto -lipsec -lcrypt
 DPADD+= ${LIBCRYPTO} ${LIBIPSEC} ${LIBCRYPT}
 .endif
+.if defined(PROG)  ${PROG} == dhclient
+LDADD+=-Wl,-Bdynamic
+.endif
 DPADD+= ${COBJDIR}/libdhcp.a
 DPADD+= ${OMOBJDIR}/libomapi.a ${DSTOBJDIR}/libdst.a
 DPADD+=	${LIBDNS} ${LIBISC}



CVS commit: src/external/bsd/nvi/usr.bin/nvi

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 03:04:06 UTC 2015

Modified Files:
src/external/bsd/nvi/usr.bin/nvi: Makefile

Log Message:
add QUEUEDEBUG commented out


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/external/bsd/nvi/usr.bin/nvi/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/nvi/usr.bin/nvi/Makefile
diff -u src/external/bsd/nvi/usr.bin/nvi/Makefile:1.5 src/external/bsd/nvi/usr.bin/nvi/Makefile:1.6
--- src/external/bsd/nvi/usr.bin/nvi/Makefile:1.5	Fri May 23 15:59:17 2014
+++ src/external/bsd/nvi/usr.bin/nvi/Makefile	Thu Jan 22 22:04:06 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.5 2014/05/23 19:59:17 dholland Exp $
+#	$NetBSD: Makefile,v 1.6 2015/01/23 03:04:06 christos Exp $
 
 .include bsd.own.mk
 
@@ -10,6 +10,7 @@ CPPFLAGS+=-I${DIST}/include -I${.CURDIR}
 #DBG=-g
 #CPPFLAGS+=-DLOGDEBUG -DTRACE
 #CPPFLAGS+=-DDBDEBUG -DTRACE
+#CPPFLAGS+=-DQUEUEDEBUG
 
 #CWARNFLAGS+=-Wno-parentheses -Wno-unused -Wno-missing-prototypes
 #.if defined(HAVE_GCC)



CVS commit: src/external/bsd/nvi/usr.bin/nvi

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 03:04:06 UTC 2015

Modified Files:
src/external/bsd/nvi/usr.bin/nvi: Makefile

Log Message:
add QUEUEDEBUG commented out


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/external/bsd/nvi/usr.bin/nvi/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/fs/msdosfs

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 03:33:58 UTC 2015

Modified Files:
src/sys/fs/msdosfs: msdosfs_vfsops.c

Log Message:
catch up with DPRINTF change


To generate a diff of this commit:
cvs rdiff -u -r1.116 -r1.117 src/sys/fs/msdosfs/msdosfs_vfsops.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/fs/msdosfs

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 23 03:33:58 UTC 2015

Modified Files:
src/sys/fs/msdosfs: msdosfs_vfsops.c

Log Message:
catch up with DPRINTF change


To generate a diff of this commit:
cvs rdiff -u -r1.116 -r1.117 src/sys/fs/msdosfs/msdosfs_vfsops.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/fs/msdosfs/msdosfs_vfsops.c
diff -u src/sys/fs/msdosfs/msdosfs_vfsops.c:1.116 src/sys/fs/msdosfs/msdosfs_vfsops.c:1.117
--- src/sys/fs/msdosfs/msdosfs_vfsops.c:1.116	Thu Jan 22 21:39:48 2015
+++ src/sys/fs/msdosfs/msdosfs_vfsops.c	Thu Jan 22 22:33:58 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: msdosfs_vfsops.c,v 1.116 2015/01/23 02:39:48 christos Exp $	*/
+/*	$NetBSD: msdosfs_vfsops.c,v 1.117 2015/01/23 03:33:58 christos Exp $	*/
 
 /*-
  * Copyright (C) 1994, 1995, 1997 Wolfgang Solfrank.
@@ -48,7 +48,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: msdosfs_vfsops.c,v 1.116 2015/01/23 02:39:48 christos Exp $);
+__KERNEL_RCSID(0, $NetBSD: msdosfs_vfsops.c,v 1.117 2015/01/23 03:33:58 christos Exp $);
 
 #if defined(_KERNEL_OPT)
 #include opt_compat_netbsd.h
@@ -511,7 +511,7 @@ msdosfs_mountfs(struct vnode *devvp, str
 	 * boot signature.  If not a dos boot sector then error out.
 	 */
 	if (secsize  sizeof(*b50)) {
-		DPRINTF((50 bootsec %u\n, secsize));
+		DPRINTF(50 bootsec %u\n, secsize);
 		error = EINVAL;
 		goto error_exit;
 	}
@@ -557,7 +557,7 @@ msdosfs_mountfs(struct vnode *devvp, str
 		pmp-pm_HugeSectors = getulong(b50-bpbHugeSectors);
 	} else {
 		if (secsize  sizeof(*b33)) {
-			DPRINTF((33 bootsec %u\n, secsize));
+			DPRINTF(33 bootsec %u\n, secsize);
 			error = EINVAL;
 			goto error_exit;
 		}
@@ -590,7 +590,7 @@ msdosfs_mountfs(struct vnode *devvp, str
 
 	if (pmp-pm_RootDirEnts == 0) {
 		if (secsize  sizeof(*b710)) {
-			DPRINTF((710 bootsec %u\n, secsize));
+			DPRINTF(710 bootsec %u\n, secsize);
 			error = EINVAL;
 			goto error_exit;
 		}
@@ -666,7 +666,7 @@ msdosfs_mountfs(struct vnode *devvp, str
 	pmp-pm_fatblk = pmp-pm_ResSectors;
 	if (FAT32(pmp)) {
 		if (secsize  sizeof(*b710)) {
-			DPRINTF((710 bootsec %u\n, secsize));
+			DPRINTF(710 bootsec %u\n, secsize);
 			error = EINVAL;
 			goto error_exit;
 		}



CVS commit: src/sys/arch/next68k/stand/boot

2015-01-22 Thread Chuck Silvers
Module Name:src
Committed By:   chs
Date:   Fri Jan 23 03:36:58 UTC 2015

Modified Files:
src/sys/arch/next68k/stand/boot: en.c

Log Message:
fix build with gcc48.


To generate a diff of this commit:
cvs rdiff -u -r1.17 -r1.18 src/sys/arch/next68k/stand/boot/en.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/next68k/stand/boot

2015-01-22 Thread Chuck Silvers
Module Name:src
Committed By:   chs
Date:   Fri Jan 23 03:36:58 UTC 2015

Modified Files:
src/sys/arch/next68k/stand/boot: en.c

Log Message:
fix build with gcc48.


To generate a diff of this commit:
cvs rdiff -u -r1.17 -r1.18 src/sys/arch/next68k/stand/boot/en.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/next68k/stand/boot/en.c
diff -u src/sys/arch/next68k/stand/boot/en.c:1.17 src/sys/arch/next68k/stand/boot/en.c:1.18
--- src/sys/arch/next68k/stand/boot/en.c:1.17	Mon Oct 26 19:16:57 2009
+++ src/sys/arch/next68k/stand/boot/en.c	Fri Jan 23 03:36:58 2015
@@ -1,4 +1,4 @@
-/*  $NetBSD: en.c,v 1.17 2009/10/26 19:16:57 cegger Exp $*/
+/*  $NetBSD: en.c,v 1.18 2015/01/23 03:36:58 chs Exp $*/
 /*
  * Copyright (c) 1996 Rolf Grossmann
  * All rights reserved.
@@ -277,13 +277,17 @@ en_get(struct iodesc *desc, void *pkt, s
 {
 	volatile struct en_regs *er;
 	volatile struct dma_dev *rxdma;
+#if 0
 	volatile struct dma_dev *txdma;
+#endif
 	int state, rxs;
 	size_t rlen;
 	char *gotpkt;
 
 	rxdma = (struct dma_dev *)P_ENETR_CSR;
+#if 0
 	txdma = (struct dma_dev *)P_ENETX_CSR;
+#endif
 	er = (struct en_regs *)P_ENET;
 
 	DPRINTF((en_get: rxdma-dd_csr = %x\n,rxdma-dd_csr));



CVS commit: src/sys/arch/cesfic/conf

2015-01-22 Thread Chuck Silvers
Module Name:src
Committed By:   chs
Date:   Fri Jan 23 03:39:39 UTC 2015

Modified Files:
src/sys/arch/cesfic/conf: Makefile.cesfic

Log Message:
fix build with gcc48.


To generate a diff of this commit:
cvs rdiff -u -r1.16 -r1.17 src/sys/arch/cesfic/conf/Makefile.cesfic

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/cesfic/conf

2015-01-22 Thread Chuck Silvers
Module Name:src
Committed By:   chs
Date:   Fri Jan 23 03:39:39 UTC 2015

Modified Files:
src/sys/arch/cesfic/conf: Makefile.cesfic

Log Message:
fix build with gcc48.


To generate a diff of this commit:
cvs rdiff -u -r1.16 -r1.17 src/sys/arch/cesfic/conf/Makefile.cesfic

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/cesfic/conf/Makefile.cesfic
diff -u src/sys/arch/cesfic/conf/Makefile.cesfic:1.16 src/sys/arch/cesfic/conf/Makefile.cesfic:1.17
--- src/sys/arch/cesfic/conf/Makefile.cesfic:1.16	Fri Jan 21 15:59:05 2011
+++ src/sys/arch/cesfic/conf/Makefile.cesfic	Fri Jan 23 03:39:39 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.cesfic,v 1.16 2011/01/21 15:59:05 joerg Exp $
+#	$NetBSD: Makefile.cesfic,v 1.17 2015/01/23 03:39:39 chs Exp $
 
 # Makefile for NetBSD
 #
@@ -35,7 +35,7 @@ CPPFLAGS+=	-Dcesfic
 CWARNFLAGS+=	-Wno-format
 CFLAGS+=	-msoft-float
 AFLAGS+=	-x assembler-with-cpp
-AFLAGS+=	-Wa,-m68040 -Wa,-m68030 -Wa,-m68851
+AFLAGS+=	-Wa,-mcpu=68030 -Wa,-m68040 -Wa,-m68030 -Wa,-m68851
 
 ##
 ## (3) libkern and compat



CVS commit: src

2015-01-22 Thread Chuck Silvers
Module Name:src
Committed By:   chs
Date:   Fri Jan 23 03:40:25 UTC 2015

Modified Files:
src/distrib/mvme68k/ramdisk: Makefile
src/sys/arch/mvme68k/conf: RAMDISK

Log Message:
increase ramdisk size for gcc48.


To generate a diff of this commit:
cvs rdiff -u -r1.28 -r1.29 src/distrib/mvme68k/ramdisk/Makefile
cvs rdiff -u -r1.29 -r1.30 src/sys/arch/mvme68k/conf/RAMDISK

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/mvme68k/ramdisk/Makefile
diff -u src/distrib/mvme68k/ramdisk/Makefile:1.28 src/distrib/mvme68k/ramdisk/Makefile:1.29
--- src/distrib/mvme68k/ramdisk/Makefile:1.28	Sun Sep 20 19:49:09 2009
+++ src/distrib/mvme68k/ramdisk/Makefile	Fri Jan 23 03:40:25 2015
@@ -1,10 +1,10 @@
-#	$NetBSD: Makefile,v 1.28 2009/09/20 19:49:09 abs Exp $
+#	$NetBSD: Makefile,v 1.29 2015/01/23 03:40:25 chs Exp $
 
 .include bsd.own.mk
 .include ${NETBSDSRCDIR}/distrib/common/Makefile.distrib
 
 IMAGE=		ramdisk.fs
-IMAGESIZE=	1m
+IMAGESIZE=	1200k
 
 WARNS=		1
 DBG=		-Os

Index: src/sys/arch/mvme68k/conf/RAMDISK
diff -u src/sys/arch/mvme68k/conf/RAMDISK:1.29 src/sys/arch/mvme68k/conf/RAMDISK:1.30
--- src/sys/arch/mvme68k/conf/RAMDISK:1.29	Sat Jul  5 09:21:14 2014
+++ src/sys/arch/mvme68k/conf/RAMDISK	Fri Jan 23 03:40:25 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: RAMDISK,v 1.29 2014/07/05 09:21:14 tsutsui Exp $
+#	$NetBSD: RAMDISK,v 1.30 2015/01/23 03:40:25 chs Exp $
 
 #
 # RAMDISK: Root/swap on ramdisk
@@ -46,7 +46,7 @@ options 	INET6		# IPV6
 # Enable the hooks used for initializing the ram-disk.
 options 	MEMORY_DISK_HOOKS
 options 	MEMORY_DISK_IS_ROOT
-options 	MEMORY_DISK_ROOT_SIZE=2100
+options 	MEMORY_DISK_ROOT_SIZE=2400
 options 	MEMORY_DISK_RBFLAGS=RB_SINGLE	# boot in single-user mode
 
 options 	USERCONF	# userconf(4) support



CVS commit: src

2015-01-22 Thread Chuck Silvers
Module Name:src
Committed By:   chs
Date:   Fri Jan 23 03:40:25 UTC 2015

Modified Files:
src/distrib/mvme68k/ramdisk: Makefile
src/sys/arch/mvme68k/conf: RAMDISK

Log Message:
increase ramdisk size for gcc48.


To generate a diff of this commit:
cvs rdiff -u -r1.28 -r1.29 src/distrib/mvme68k/ramdisk/Makefile
cvs rdiff -u -r1.29 -r1.30 src/sys/arch/mvme68k/conf/RAMDISK

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/usr.sbin/mtree

2015-01-22 Thread Thomas Klausner
Module Name:src
Committed By:   wiz
Date:   Fri Jan 23 03:31:58 UTC 2015

Modified Files:
src/usr.sbin/mtree: mtree.8

Log Message:
Pull into this year.


To generate a diff of this commit:
cvs rdiff -u -r1.70 -r1.71 src/usr.sbin/mtree/mtree.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/usr.sbin/mtree

2015-01-22 Thread Thomas Klausner
Module Name:src
Committed By:   wiz
Date:   Fri Jan 23 03:31:58 UTC 2015

Modified Files:
src/usr.sbin/mtree: mtree.8

Log Message:
Pull into this year.


To generate a diff of this commit:
cvs rdiff -u -r1.70 -r1.71 src/usr.sbin/mtree/mtree.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.sbin/mtree/mtree.8
diff -u src/usr.sbin/mtree/mtree.8:1.70 src/usr.sbin/mtree/mtree.8:1.71
--- src/usr.sbin/mtree/mtree.8:1.70	Fri Jan 23 02:27:01 2015
+++ src/usr.sbin/mtree/mtree.8	Fri Jan 23 03:31:58 2015
@@ -1,4 +1,4 @@
-.\	$NetBSD: mtree.8,v 1.70 2015/01/23 02:27:01 christos Exp $
+.\	$NetBSD: mtree.8,v 1.71 2015/01/23 03:31:58 wiz Exp $
 .\
 .\ Copyright (c) 1989, 1990, 1993
 .\	The Regents of the University of California.  All rights reserved.
@@ -56,7 +56,7 @@
 .\
 .\ @(#)mtree.8	8.2 (Berkeley) 12/11/93
 .\
-.Dd January 22, 2014
+.Dd January 22, 2015
 .Dt MTREE 8
 .Os
 .Sh NAME



CVS commit: src/share/mk

2015-01-22 Thread Chuck Silvers
Module Name:src
Committed By:   chs
Date:   Fri Jan 23 03:43:24 UTC 2015

Modified Files:
src/share/mk: bsd.own.mk

Log Message:
switch m68k to use gcc48.


To generate a diff of this commit:
cvs rdiff -u -r1.841 -r1.842 src/share/mk/bsd.own.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/mk/bsd.own.mk
diff -u src/share/mk/bsd.own.mk:1.841 src/share/mk/bsd.own.mk:1.842
--- src/share/mk/bsd.own.mk:1.841	Mon Jan  5 03:45:31 2015
+++ src/share/mk/bsd.own.mk	Fri Jan 23 03:43:24 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: bsd.own.mk,v 1.841 2015/01/05 03:45:31 mrg Exp $
+#	$NetBSD: bsd.own.mk,v 1.842 2015/01/23 03:43:24 chs Exp $
 
 # This needs to be before bsd.init.mk
 .if defined(BSD_MK_COMPAT_FILE)
@@ -61,12 +61,7 @@ MKGCC?=		no
 #
 .if ${MKGCC:Uyes} != no
 
-# Platforms still using GCC 4.5
-.if \
-  ${MACHINE_CPU} == m68k
-HAVE_GCC?=45
-
-.elif ${MACHINE} == playstation2 || ${MACHINE_CPU} == aarch64
+.if ${MACHINE} == playstation2 || ${MACHINE_CPU} == aarch64
 HAVE_GCC?=0
 .else
 # Otherwise, default to GCC4.8



CVS commit: src/share/mk

2015-01-22 Thread Chuck Silvers
Module Name:src
Committed By:   chs
Date:   Fri Jan 23 03:43:24 UTC 2015

Modified Files:
src/share/mk: bsd.own.mk

Log Message:
switch m68k to use gcc48.


To generate a diff of this commit:
cvs rdiff -u -r1.841 -r1.842 src/share/mk/bsd.own.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/powerpc/booke

2015-01-22 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Fri Jan 23 06:16:23 UTC 2015

Modified Files:
src/sys/arch/powerpc/booke: e500_intr.c

Log Message:
Allow to share IPI interrupt.


To generate a diff of this commit:
cvs rdiff -u -r1.29 -r1.30 src/sys/arch/powerpc/booke/e500_intr.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/booke/e500_intr.c
diff -u src/sys/arch/powerpc/booke/e500_intr.c:1.29 src/sys/arch/powerpc/booke/e500_intr.c:1.30
--- src/sys/arch/powerpc/booke/e500_intr.c:1.29	Mon Jan  5 07:40:05 2015
+++ src/sys/arch/powerpc/booke/e500_intr.c	Fri Jan 23 06:16:23 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: e500_intr.c,v 1.29 2015/01/05 07:40:05 nonaka Exp $	*/
+/*	$NetBSD: e500_intr.c,v 1.30 2015/01/23 06:16:23 nonaka Exp $	*/
 /*-
  * Copyright (c) 2010, 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -39,7 +39,7 @@
 #define __INTR_PRIVATE
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: e500_intr.c,v 1.29 2015/01/05 07:40:05 nonaka Exp $);
+__KERNEL_RCSID(0, $NetBSD: e500_intr.c,v 1.30 2015/01/23 06:16:23 nonaka Exp $);
 
 #include sys/param.h
 #include sys/proc.h
@@ -83,6 +83,7 @@ struct intr_source {
 	int8_t is_ipl;
 	uint8_t is_ist;
 	uint8_t is_irq;
+	uint8_t is_refcnt;
 	bus_size_t is_vpr;
 	bus_size_t is_dr;
 };
@@ -737,8 +738,16 @@ e500_intr_cpu_establish(struct cpu_info 
 	struct intr_source * const is = e500_intr_sources[ii.irq_vector];
 	mutex_enter(e500_intr_lock);
 	if (is-is_ipl != IPL_NONE) {
-		mutex_exit(e500_intr_lock);
-		return NULL;
+		/* XXX IPI0 is shared by all CPU. */
+		if (is-is_ist != IST_IPI ||
+		is-is_irq != irq ||
+		is-is_ipl != ipl ||
+		is-is_ist != ist ||
+		is-is_func != handler ||
+		is-is_arg != arg) {
+			mutex_exit(e500_intr_lock);
+			return NULL;
+		}
 	}
 
 	is-is_func = handler;
@@ -746,6 +755,7 @@ e500_intr_cpu_establish(struct cpu_info 
 	is-is_ipl = ipl;
 	is-is_ist = ist;
 	is-is_irq = irq;
+	is-is_refcnt++;
 	is-is_vpr = ii.irq_vpr;
 	is-is_dr = ii.irq_dr;
 
@@ -812,6 +822,12 @@ e500_intr_disestablish(void *vis)
 	KASSERT(is - e500_intr_sources == ii.irq_vector);
 
 	mutex_enter(e500_intr_lock);
+
+	if (is-is_refcnt--  1) {
+		mutex_exit(e500_intr_lock);
+		return;
+	}
+
 	/*
 	 * Mask the source using the mask (MSK) bit in the vector/priority reg.
 	 */



CVS commit: src/sys/arch/powerpc/booke

2015-01-22 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Fri Jan 23 06:16:23 UTC 2015

Modified Files:
src/sys/arch/powerpc/booke: e500_intr.c

Log Message:
Allow to share IPI interrupt.


To generate a diff of this commit:
cvs rdiff -u -r1.29 -r1.30 src/sys/arch/powerpc/booke/e500_intr.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/lib/libutil

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 22 19:04:28 UTC 2015

Modified Files:
src/lib/libutil: pidfile.c

Log Message:
s/basename/bname/


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/lib/libutil/pidfile.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/config/main.c
diff -u src/usr.bin/config/main.c:1.73 src/usr.bin/config/main.c:1.74
--- src/usr.bin/config/main.c:1.73	Thu Nov  6 06:40:32 2014
+++ src/usr.bin/config/main.c	Thu Jan 22 15:01:22 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: main.c,v 1.73 2014/11/06 11:40:32 uebayasi Exp $	*/
+/*	$NetBSD: main.c,v 1.74 2015/01/22 20:01:22 christos Exp $	*/
 
 /*
  * Copyright (c) 1992, 1993
@@ -45,7 +45,7 @@
 #endif
 
 #include sys/cdefs.h
-__RCSID($NetBSD: main.c,v 1.73 2014/11/06 11:40:32 uebayasi Exp $);
+__RCSID($NetBSD: main.c,v 1.74 2015/01/22 20:01:22 christos Exp $);
 
 #ifndef MAKE_BOOTSTRAP
 #include sys/cdefs.h
@@ -1557,8 +1557,8 @@ strtolower(const char *name)
 	char c;
 
 	for (n = name, p = low; (c = *n) != '\0'; n++)
-		*p++ = isupper((u_char)c) ? (char)tolower((u_char)c) : c;
-	*p = 0;
+		*p++ = (char)(isupper((u_char)c) ? tolower((u_char)c) : c);
+	*p = '\0';
 	return (intern(low));
 }
 

Index: src/usr.bin/config/mkheaders.c
diff -u src/usr.bin/config/mkheaders.c:1.25 src/usr.bin/config/mkheaders.c:1.26
--- src/usr.bin/config/mkheaders.c:1.25	Tue Nov  4 18:00:35 2014
+++ src/usr.bin/config/mkheaders.c	Thu Jan 22 15:01:22 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: mkheaders.c,v 1.25 2014/11/04 23:00:35 joerg Exp $	*/
+/*	$NetBSD: mkheaders.c,v 1.26 2015/01/22 20:01:22 christos Exp $	*/
 
 /*
  * Copyright (c) 1992, 1993
@@ -45,7 +45,7 @@
 #endif
 
 #include sys/cdefs.h
-__RCSID($NetBSD: mkheaders.c,v 1.25 2014/11/04 23:00:35 joerg Exp $);
+__RCSID($NetBSD: mkheaders.c,v 1.26 2015/01/22 20:01:22 christos Exp $);
 
 #include sys/param.h
 #include ctype.h
@@ -533,7 +533,7 @@ cntname(const char *src)
 	dst = buf;
 	*dst++ = 'N';
 	while ((c = *src++) != 0)
-		*dst++ = islower((u_char)c) ? (char)toupper((u_char)c) : c;
+		*dst++ = (char)(islower((u_char)c) ? toupper((u_char)c) : c);
 	*dst = 0;
 	return (buf);
 }



CVS commit: src/usr.bin/config

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 22 20:01:22 UTC 2015

Modified Files:
src/usr.bin/config: main.c mkheaders.c

Log Message:
appease gcc-4.5.4


To generate a diff of this commit:
cvs rdiff -u -r1.73 -r1.74 src/usr.bin/config/main.c
cvs rdiff -u -r1.25 -r1.26 src/usr.bin/config/mkheaders.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/etc

2015-01-22 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Thu Jan 22 19:50:21 UTC 2015

Modified Files:
src/etc/defaults: rc.conf
src/etc/rc.d: wpa_supplicant

Log Message:
It doesn't make sense to start wpa_supplicant from an rc.d script without
the -B flag, so always prepend it to $rc_flags.


To generate a diff of this commit:
cvs rdiff -u -r1.128 -r1.129 src/etc/defaults/rc.conf
cvs rdiff -u -r1.5 -r1.6 src/etc/rc.d/wpa_supplicant

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/etc/defaults/rc.conf
diff -u src/etc/defaults/rc.conf:1.128 src/etc/defaults/rc.conf:1.129
--- src/etc/defaults/rc.conf:1.128	Fri Sep 26 11:04:06 2014
+++ src/etc/defaults/rc.conf	Thu Jan 22 19:50:21 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: rc.conf,v 1.128 2014/09/26 11:04:06 tron Exp $
+#	$NetBSD: rc.conf,v 1.129 2015/01/22 19:50:21 jmcneill Exp $
 #
 # /etc/defaults/rc.conf --
 #	default configuration of /etc/rc.conf
@@ -300,7 +300,7 @@ iscsi_target=NO		iscsi_target_flags=
 
 # WPA daemons.
 hostapd=NO		hostapd_flags=-B /etc/hostapd.conf
-wpa_supplicant=NO	wpa_supplicant_flags=-B # -iif -cfile
+wpa_supplicant=NO	wpa_supplicant_flags= # -iif -cfile
 
 # ISDN daemon
 isdnd=NO		isdnd_flags=

Index: src/etc/rc.d/wpa_supplicant
diff -u src/etc/rc.d/wpa_supplicant:1.5 src/etc/rc.d/wpa_supplicant:1.6
--- src/etc/rc.d/wpa_supplicant:1.5	Thu Jan 23 07:26:51 2014
+++ src/etc/rc.d/wpa_supplicant	Thu Jan 22 19:50:21 2015
@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $NetBSD: wpa_supplicant,v 1.5 2014/01/23 07:26:51 spz Exp $
+# $NetBSD: wpa_supplicant,v 1.6 2015/01/22 19:50:21 jmcneill Exp $
 #
 
 # PROVIDE: wpa_supplicant
@@ -29,6 +29,7 @@ wpa_supplicant_precmd()
 if [ ! -d /var/run/wpa_supplicant ]; then
 mkdir -p -m 755 /var/run/wpa_supplicant
 fi
+rc_flags=-B $rc_flags
 }
 
 load_rc_config $name



CVS commit: src/sys/dev/ic

2015-01-22 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Thu Jan 22 17:06:15 UTC 2015

Modified Files:
src/sys/dev/ic: dwc_mmc.c

Log Message:
when resetting controller, dont preserve DWC_MMC_CTRL_REG state. makes this 
work on my radxa lite


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/sys/dev/ic/dwc_mmc.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/dev/ic

2015-01-22 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Thu Jan 22 17:06:15 UTC 2015

Modified Files:
src/sys/dev/ic: dwc_mmc.c

Log Message:
when resetting controller, dont preserve DWC_MMC_CTRL_REG state. makes this 
work on my radxa lite


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/sys/dev/ic/dwc_mmc.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/ic/dwc_mmc.c
diff -u src/sys/dev/ic/dwc_mmc.c:1.5 src/sys/dev/ic/dwc_mmc.c:1.6
--- src/sys/dev/ic/dwc_mmc.c:1.5	Sat Jan 17 19:10:18 2015
+++ src/sys/dev/ic/dwc_mmc.c	Thu Jan 22 17:06:15 2015
@@ -1,4 +1,4 @@
-/* $NetBSD: dwc_mmc.c,v 1.5 2015/01/17 19:10:18 jmcneill Exp $ */
+/* $NetBSD: dwc_mmc.c,v 1.6 2015/01/22 17:06:15 jmcneill Exp $ */
 
 /*-
  * Copyright (c) 2014 Jared D. McNeill jmcne...@invisible.ca
@@ -29,7 +29,7 @@
 #include opt_dwc_mmc.h
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: dwc_mmc.c,v 1.5 2015/01/17 19:10:18 jmcneill Exp $);
+__KERNEL_RCSID(0, $NetBSD: dwc_mmc.c,v 1.6 2015/01/22 17:06:15 jmcneill Exp $);
 
 #include sys/param.h
 #include sys/bus.h
@@ -290,8 +290,7 @@ dwc_mmc_host_reset(sdmmc_chipset_handle_
 		MMC_WRITE(sc, DWC_MMC_PWREN_REG, DWC_MMC_PWREN_POWER_ENABLE);
 	}
 
-	MMC_WRITE(sc, DWC_MMC_CTRL_REG,
-	MMC_READ(sc, DWC_MMC_CTRL_REG) | DWC_MMC_CTRL_RESET_ALL);
+	MMC_WRITE(sc, DWC_MMC_CTRL_REG, DWC_MMC_CTRL_RESET_ALL);
 	while (--retry  0) {
 		ctrl = MMC_READ(sc, DWC_MMC_CTRL_REG);
 		if ((ctrl  DWC_MMC_CTRL_RESET_ALL) == 0)



CVS commit: src/sys/dev/i2c

2015-01-22 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Thu Jan 22 17:56:35 UTC 2015

Modified Files:
src/sys/dev/i2c: i2c.c

Log Message:
More correctly handle I²C exec ioctls with both a command and write data
phase. Previously the data phase of ioctl writes was sending uninitialized
kernel stack to the addressed device.


To generate a diff of this commit:
cvs rdiff -u -r1.45 -r1.46 src/sys/dev/i2c/i2c.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/i2c/i2c.c
diff -u src/sys/dev/i2c/i2c.c:1.45 src/sys/dev/i2c/i2c.c:1.46
--- src/sys/dev/i2c/i2c.c:1.45	Sun Dec  7 00:32:35 2014
+++ src/sys/dev/i2c/i2c.c	Thu Jan 22 17:56:35 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: i2c.c,v 1.45 2014/12/07 00:32:35 jmcneill Exp $	*/
+/*	$NetBSD: i2c.c,v 1.46 2015/01/22 17:56:35 jakllsch Exp $	*/
 
 /*
  * Copyright (c) 2003 Wasabi Systems, Inc.
@@ -40,7 +40,7 @@
 #endif
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: i2c.c,v 1.45 2014/12/07 00:32:35 jmcneill Exp $);
+__KERNEL_RCSID(0, $NetBSD: i2c.c,v 1.46 2015/01/22 17:56:35 jakllsch Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -525,6 +525,13 @@ iic_ioctl_exec(struct iic_softc *sc, i2c
 		}
 	}
 
+	if (iie-iie_buf != NULL  I2C_OP_WRITE_P(iie-iie_op)) {
+		error = copyin(iie-iie_buf, buf, iie-iie_buflen);
+		if (error) {
+			return error;
+		}
+	}
+
 	iic_acquire_bus(ic, 0);
 	error = iic_exec(ic, iie-iie_op, iie-iie_addr, cmd, iie-iie_cmdlen,
 	buf, iie-iie_buflen, 0);
@@ -542,7 +549,7 @@ iic_ioctl_exec(struct iic_softc *sc, i2c
 	if (error)
 		return error;
 
-	if (iie-iie_buf)
+	if (iie-iie_buf != NULL  I2C_OP_READ_P(iie-iie_op))
 		error = copyout(buf, iie-iie_buf, iie-iie_buflen);
 
 	return error;



CVS commit: src/sys/dev/i2c

2015-01-22 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Thu Jan 22 17:56:35 UTC 2015

Modified Files:
src/sys/dev/i2c: i2c.c

Log Message:
More correctly handle I²C exec ioctls with both a command and write data
phase. Previously the data phase of ioctl writes was sending uninitialized
kernel stack to the addressed device.


To generate a diff of this commit:
cvs rdiff -u -r1.45 -r1.46 src/sys/dev/i2c/i2c.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/powerpc/booke

2015-01-22 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Fri Jan 23 06:39:41 UTC 2015

Modified Files:
src/sys/arch/powerpc/booke: booke_machdep.c booke_pmap.c

Log Message:
When pmap_bootstrap is called, kcpuset_running has not been created yet.


To generate a diff of this commit:
cvs rdiff -u -r1.21 -r1.22 src/sys/arch/powerpc/booke/booke_machdep.c
cvs rdiff -u -r1.20 -r1.21 src/sys/arch/powerpc/booke/booke_pmap.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/booke/booke_machdep.c
diff -u src/sys/arch/powerpc/booke/booke_machdep.c:1.21 src/sys/arch/powerpc/booke/booke_machdep.c:1.22
--- src/sys/arch/powerpc/booke/booke_machdep.c:1.21	Mon Sep 22 21:35:15 2014
+++ src/sys/arch/powerpc/booke/booke_machdep.c	Fri Jan 23 06:39:41 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: booke_machdep.c,v 1.21 2014/09/22 21:35:15 matt Exp $	*/
+/*	$NetBSD: booke_machdep.c,v 1.22 2015/01/23 06:39:41 nonaka Exp $	*/
 /*-
  * Copyright (c) 2010, 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -38,7 +38,7 @@
 #define	_POWERPC_BUS_DMA_PRIVATE
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: booke_machdep.c,v 1.21 2014/09/22 21:35:15 matt Exp $);
+__KERNEL_RCSID(0, $NetBSD: booke_machdep.c,v 1.22 2015/01/23 06:39:41 nonaka Exp $);
 
 #include opt_modular.h
 
@@ -207,6 +207,9 @@ booke_cpu_startup(const char *model)
 	fake_mapiodev = 0;
 
 #ifdef MULTIPROCESSOR
+	pmap_kernel()-pm_active = kcpuset_running;
+	pmap_kernel()-pm_onproc = kcpuset_running;
+
 	for (size_t i = 1; i  __arraycount(cpu_info); i++) {
 		struct cpu_info * const ci = cpu_info[i];
 		struct cpu_softc * const cpu = cpu_softc[i];

Index: src/sys/arch/powerpc/booke/booke_pmap.c
diff -u src/sys/arch/powerpc/booke/booke_pmap.c:1.20 src/sys/arch/powerpc/booke/booke_pmap.c:1.21
--- src/sys/arch/powerpc/booke/booke_pmap.c:1.20	Fri Jan  9 11:45:11 2015
+++ src/sys/arch/powerpc/booke/booke_pmap.c	Fri Jan 23 06:39:41 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: booke_pmap.c,v 1.20 2015/01/09 11:45:11 nonaka Exp $	*/
+/*	$NetBSD: booke_pmap.c,v 1.21 2015/01/23 06:39:41 nonaka Exp $	*/
 /*-
  * Copyright (c) 2010, 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -38,7 +38,7 @@
 
 #include sys/cdefs.h
 
-__KERNEL_RCSID(0, $NetBSD: booke_pmap.c,v 1.20 2015/01/09 11:45:11 nonaka Exp $);
+__KERNEL_RCSID(0, $NetBSD: booke_pmap.c,v 1.21 2015/01/23 06:39:41 nonaka Exp $);
 
 #include sys/param.h
 #include sys/kcore.h
@@ -160,10 +160,6 @@ pmap_bootstrap(vaddr_t startkernel, vadd
 	 */
 	pmap_kernel()-pm_segtab = stp;
 	curcpu()-ci_pmap_kern_segtab = stp;
-#ifdef MULTIPROCESSOR
-	pmap_kernel()-pm_active = kcpuset_running;
-	pmap_kernel()-pm_onproc = kcpuset_running;
-#endif
 
 	KASSERT(endkernel == trunc_page(endkernel));
 



CVS commit: src/sys/arch/powerpc/booke

2015-01-22 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Fri Jan 23 06:39:41 UTC 2015

Modified Files:
src/sys/arch/powerpc/booke: booke_machdep.c booke_pmap.c

Log Message:
When pmap_bootstrap is called, kcpuset_running has not been created yet.


To generate a diff of this commit:
cvs rdiff -u -r1.21 -r1.22 src/sys/arch/powerpc/booke/booke_machdep.c
cvs rdiff -u -r1.20 -r1.21 src/sys/arch/powerpc/booke/booke_pmap.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/powerpc/booke

2015-01-22 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Fri Jan 23 06:52:55 UTC 2015

Modified Files:
src/sys/arch/powerpc/booke: e500_tlb.c

Log Message:
- Use tlbivax instruction for TLB update/invalidate when MULTIPROCESSOR is
  defined. Because TLB entry operation is not notified to another CPU.
- When TLB1 is updated, send IPI_TLB1SYNC to another CPU.


To generate a diff of this commit:
cvs rdiff -u -r1.15 -r1.16 src/sys/arch/powerpc/booke/e500_tlb.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/booke/e500_tlb.c
diff -u src/sys/arch/powerpc/booke/e500_tlb.c:1.15 src/sys/arch/powerpc/booke/e500_tlb.c:1.16
--- src/sys/arch/powerpc/booke/e500_tlb.c:1.15	Sun Dec 28 14:13:56 2014
+++ src/sys/arch/powerpc/booke/e500_tlb.c	Fri Jan 23 06:52:55 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: e500_tlb.c,v 1.15 2014/12/28 14:13:56 nonaka Exp $	*/
+/*	$NetBSD: e500_tlb.c,v 1.16 2015/01/23 06:52:55 nonaka Exp $	*/
 /*-
  * Copyright (c) 2010, 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -40,7 +40,7 @@
 
 #include sys/cdefs.h
 
-__KERNEL_RCSID(0, $NetBSD: e500_tlb.c,v 1.15 2014/12/28 14:13:56 nonaka Exp $);
+__KERNEL_RCSID(0, $NetBSD: e500_tlb.c,v 1.16 2015/01/23 06:52:55 nonaka Exp $);
 
 #include sys/param.h
 
@@ -372,6 +372,9 @@ e500_tlb_invalidate_all(void)
 static void
 e500_tlb_invalidate_globals(void)
 {
+#if defined(MULTIPROCESSOR)
+	e500_tlb_invalidate_all();
+#else	/* !MULTIPROCESSOR */
 	const size_t tlbassoc = TLBCFG_ASSOC(mftlb0cfg());
 	const size_t tlbentries = TLBCFG_NENTRY(mftlb0cfg());
 	const size_t max_epn = (tlbentries / tlbassoc)  PAGE_SHIFT;
@@ -416,11 +419,15 @@ e500_tlb_invalidate_globals(void)
 	}
 	__asm volatile(isync\n\tsync);
 	wrtee(msr);
+#endif	/* MULTIPROCESSOR */
 }
 
 static void
 e500_tlb_invalidate_asids(tlb_asid_t asid_lo, tlb_asid_t asid_hi)
 {
+#if defined(MULTIPROCESSOR)
+	e500_tlb_invalidate_all();
+#else	/* !MULTIPROCESSOR */
 	const size_t tlbassoc = TLBCFG_ASSOC(mftlb0cfg());
 	const size_t tlbentries = TLBCFG_NENTRY(mftlb0cfg());
 	const size_t max_epn = (tlbentries / tlbassoc)  PAGE_SHIFT;
@@ -454,6 +461,7 @@ e500_tlb_invalidate_asids(tlb_asid_t asi
 	}
 	__asm volatile(isync\n\tsync);
 	wrtee(msr);
+#endif	/* MULTIPROCESSOR */
 }
 
 static u_int
@@ -525,6 +533,10 @@ e500_tlb_invalidate_addr(vaddr_t va, tlb
 static bool
 e500_tlb_update_addr(vaddr_t va, tlb_asid_t asid, pt_entry_t pte, bool insert)
 {
+#if defined(MULTIPROCESSOR)
+	e500_tlb_invalidate_addr(va, asid);
+	return true;
+#else	/* !MULTIPROCESSOR */
 	struct e500_hwtlb hwtlb = tlb_to_hwtlb(
 	(struct e500_tlb){ .tlb_va = va, .tlb_asid = asid,
 		.tlb_size = PAGE_SIZE, .tlb_pte = pte,});
@@ -558,6 +570,7 @@ e500_tlb_update_addr(vaddr_t va, tlb_asi
 	hwtlb.hwtlb_mas1, hwtlb.hwtlb_mas2, hwtlb.hwtlb_mas3);
 #endif
 	return (mas1  MAS1_V) != 0;
+#endif	/* MULTIPROCESSOR */
 }
 
 static void
@@ -788,6 +801,11 @@ e500_tlb_ioreserve(vaddr_t va, vsize_t l
 	xtlb-e_hwtlb = tlb_to_hwtlb(xtlb-e_tlb);
 	xtlb-e_hwtlb.hwtlb_mas0 |= __SHIFTIN(slot, MAS0_ESEL);
 	hwtlb_write(xtlb-e_hwtlb, true);
+
+#if defined(MULTIPROCESSOR)
+	cpu_send_ipi(IPI_DST_NOTME, IPI_TLB1SYNC);
+#endif
+
 	return 0;
 }
 
@@ -805,6 +823,10 @@ e500_tlb_iorelease(vaddr_t va)
 
 	e500_free_tlb1_entry(xtlb, slot, true);
 
+#if defined(MULTIPROCESSOR)
+	cpu_send_ipi(IPI_DST_NOTME, IPI_TLB1SYNC);
+#endif
+
 	return 0;
 }
 
@@ -841,6 +863,10 @@ e500_tlbmemmap(paddr_t memstart, psize_t
 		}
 	}
 
+#if defined(MULTIPROCESSOR)
+	cpu_send_ipi(IPI_DST_NOTME, IPI_TLB1SYNC);
+#endif
+
 	return nextslot;
 }
 



CVS commit: src/sys/arch/powerpc/booke/dev

2015-01-22 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Fri Jan 23 06:58:33 UTC 2015

Modified Files:
src/sys/arch/powerpc/booke/dev: pq3etsec.c

Log Message:
Avoid if_snd race condition when MP.


To generate a diff of this commit:
cvs rdiff -u -r1.23 -r1.24 src/sys/arch/powerpc/booke/dev/pq3etsec.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/booke/dev/pq3etsec.c
diff -u src/sys/arch/powerpc/booke/dev/pq3etsec.c:1.23 src/sys/arch/powerpc/booke/dev/pq3etsec.c:1.24
--- src/sys/arch/powerpc/booke/dev/pq3etsec.c:1.23	Fri Jan 16 07:48:16 2015
+++ src/sys/arch/powerpc/booke/dev/pq3etsec.c	Fri Jan 23 06:58:32 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: pq3etsec.c,v 1.23 2015/01/16 07:48:16 nonaka Exp $	*/
+/*	$NetBSD: pq3etsec.c,v 1.24 2015/01/23 06:58:32 nonaka Exp $	*/
 /*-
  * Copyright (c) 2010, 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -36,10 +36,12 @@
 
 #include opt_inet.h
 #include opt_mpc85xx.h
+#include opt_multiprocessor.h
+#include opt_net_mpsafe.h
 
 #include sys/cdefs.h
 
-__KERNEL_RCSID(0, $NetBSD: pq3etsec.c,v 1.23 2015/01/16 07:48:16 nonaka Exp $);
+__KERNEL_RCSID(0, $NetBSD: pq3etsec.c,v 1.24 2015/01/23 06:58:32 nonaka Exp $);
 
 #include sys/param.h
 #include sys/cpu.h
@@ -677,7 +679,11 @@ pq3etsec_attach(device_t parent, device_
 		return;
 	}
 
-	sc-sc_soft_ih = softint_establish(SOFTINT_NET|SOFTINT_MPSAFE,
+	int softint_flags = SOFTINT_NET;
+#if !defined(MULTIPROCESSOR) || defined(NET_MPSAFE)
+	softint_flags |= SOFTINT_MPSAFE;
+#endif	/* !MULTIPROCESSOR || NET_MPSAFE */
+	sc-sc_soft_ih = softint_establish(softint_flags,
 	pq3etsec_soft_intr, sc);
 	if (sc-sc_soft_ih == NULL) {
 		aprint_error(: failed to establish soft interrupt\n);



CVS commit: src/sys/arch/powerpc/booke/dev

2015-01-22 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Fri Jan 23 06:58:33 UTC 2015

Modified Files:
src/sys/arch/powerpc/booke/dev: pq3etsec.c

Log Message:
Avoid if_snd race condition when MP.


To generate a diff of this commit:
cvs rdiff -u -r1.23 -r1.24 src/sys/arch/powerpc/booke/dev/pq3etsec.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch

2015-01-22 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Fri Jan 23 07:27:06 UTC 2015

Modified Files:
src/sys/arch/evbppc/mpc85xx: machdep.c
src/sys/arch/powerpc/booke: booke_machdep.c e500_intr.c
src/sys/arch/powerpc/include: cpu.h db_machdep.h
src/sys/arch/powerpc/include/booke: intr.h
src/sys/arch/powerpc/pic: ipi.c ipivar.h
src/sys/arch/powerpc/powerpc: db_interface.c powerpc_machdep.c

Log Message:
ddb MP support


To generate a diff of this commit:
cvs rdiff -u -r1.39 -r1.40 src/sys/arch/evbppc/mpc85xx/machdep.c
cvs rdiff -u -r1.22 -r1.23 src/sys/arch/powerpc/booke/booke_machdep.c
cvs rdiff -u -r1.30 -r1.31 src/sys/arch/powerpc/booke/e500_intr.c
cvs rdiff -u -r1.100 -r1.101 src/sys/arch/powerpc/include/cpu.h
cvs rdiff -u -r1.24 -r1.25 src/sys/arch/powerpc/include/db_machdep.h
cvs rdiff -u -r1.8 -r1.9 src/sys/arch/powerpc/include/booke/intr.h
cvs rdiff -u -r1.11 -r1.12 src/sys/arch/powerpc/pic/ipi.c
cvs rdiff -u -r1.7 -r1.8 src/sys/arch/powerpc/pic/ipivar.h
cvs rdiff -u -r1.52 -r1.53 src/sys/arch/powerpc/powerpc/db_interface.c
cvs rdiff -u -r1.70 -r1.71 src/sys/arch/powerpc/powerpc/powerpc_machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbppc/mpc85xx/machdep.c
diff -u src/sys/arch/evbppc/mpc85xx/machdep.c:1.39 src/sys/arch/evbppc/mpc85xx/machdep.c:1.40
--- src/sys/arch/evbppc/mpc85xx/machdep.c:1.39	Tue Jan  6 01:23:24 2015
+++ src/sys/arch/evbppc/mpc85xx/machdep.c	Fri Jan 23 07:27:05 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: machdep.c,v 1.39 2015/01/06 01:23:24 nonaka Exp $	*/
+/*	$NetBSD: machdep.c,v 1.40 2015/01/23 07:27:05 nonaka Exp $	*/
 /*-
  * Copyright (c) 2010, 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -41,6 +41,7 @@ __KERNEL_RCSID(0, $NetSBD$);
 #include opt_altivec.h
 #include opt_ddb.h
 #include opt_mpc85xx.h
+#include opt_multiprocessor.h
 #include opt_pci.h
 #include gpio.h
 #include pci.h
@@ -1054,6 +1055,13 @@ e500_cpu_attach(device_t self, u_int ins
 void
 e500_ipi_halt(void)
 {
+#ifdef MULTIPROCESSOR
+	struct cpuset_info * const csi = cpuset_info;
+	const cpuid_t index = cpu_index(curcpu());
+
+	printf(cpu%lu: shutting down\n, index);
+	kcpuset_set(csi-cpus_halted, index);
+#endif
 	register_t msr, hid0;
 
 	msr = wrtee(0);

Index: src/sys/arch/powerpc/booke/booke_machdep.c
diff -u src/sys/arch/powerpc/booke/booke_machdep.c:1.22 src/sys/arch/powerpc/booke/booke_machdep.c:1.23
--- src/sys/arch/powerpc/booke/booke_machdep.c:1.22	Fri Jan 23 06:39:41 2015
+++ src/sys/arch/powerpc/booke/booke_machdep.c	Fri Jan 23 07:27:05 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: booke_machdep.c,v 1.22 2015/01/23 06:39:41 nonaka Exp $	*/
+/*	$NetBSD: booke_machdep.c,v 1.23 2015/01/23 07:27:05 nonaka Exp $	*/
 /*-
  * Copyright (c) 2010, 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -38,7 +38,7 @@
 #define	_POWERPC_BUS_DMA_PRIVATE
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: booke_machdep.c,v 1.22 2015/01/23 06:39:41 nonaka Exp $);
+__KERNEL_RCSID(0, $NetBSD: booke_machdep.c,v 1.23 2015/01/23 07:27:05 nonaka Exp $);
 
 #include opt_modular.h
 
@@ -230,6 +230,8 @@ booke_cpu_startup(const char *model)
 	kcpuset_create(cpuset_info.cpus_paused, true);
 	kcpuset_create(cpuset_info.cpus_resumed, true);
 	kcpuset_create(cpuset_info.cpus_halted, true);
+
+	kcpuset_set(cpuset_info.cpus_running, cpu_number());
 #endif /* MULTIPROCESSOR */
 }
 

Index: src/sys/arch/powerpc/booke/e500_intr.c
diff -u src/sys/arch/powerpc/booke/e500_intr.c:1.30 src/sys/arch/powerpc/booke/e500_intr.c:1.31
--- src/sys/arch/powerpc/booke/e500_intr.c:1.30	Fri Jan 23 06:16:23 2015
+++ src/sys/arch/powerpc/booke/e500_intr.c	Fri Jan 23 07:27:05 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: e500_intr.c,v 1.30 2015/01/23 06:16:23 nonaka Exp $	*/
+/*	$NetBSD: e500_intr.c,v 1.31 2015/01/23 07:27:05 nonaka Exp $	*/
 /*-
  * Copyright (c) 2010, 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -35,11 +35,13 @@
  */
 
 #include opt_mpc85xx.h
+#include opt_multiprocessor.h
+#include opt_ddb.h
 
 #define __INTR_PRIVATE
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: e500_intr.c,v 1.30 2015/01/23 06:16:23 nonaka Exp $);
+__KERNEL_RCSID(0, $NetBSD: e500_intr.c,v 1.31 2015/01/23 07:27:05 nonaka Exp $);
 
 #include sys/param.h
 #include sys/proc.h
@@ -1268,6 +1270,15 @@ e500_ipi_kpreempt(void)
 }
 #endif
 
+static void
+e500_ipi_suspend(void)
+{
+
+#ifdef MULTIPROCESSOR
+	cpu_pause(NULL);
+#endif	/* MULTIPROCESSOR */
+}
+
 static const ipifunc_t e500_ipifuncs[] = {
 	[ilog2(IPI_XCALL)] =	xc_ipi_handler,
 	[ilog2(IPI_GENERIC)] =	ipi_cpu_handler,
@@ -1276,6 +1287,7 @@ static const ipifunc_t e500_ipifuncs[] =
 	[ilog2(IPI_KPREEMPT)] =	e500_ipi_kpreempt,
 #endif
 	[ilog2(IPI_TLB1SYNC)] =	e500_tlb1_sync,
+	[ilog2(IPI_SUSPEND)] =	e500_ipi_suspend,
 };
 
 static int

Index: src/lib/libutil/pidfile.c
diff -u src/lib/libutil/pidfile.c:1.10 src/lib/libutil/pidfile.c:1.11
--- src/lib/libutil/pidfile.c:1.10	Thu Jan 22 11:19:08 2015
+++ src/lib/libutil/pidfile.c	Thu Jan 22 14:04:28 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: pidfile.c,v 1.10 2015/01/22 16:19:08 christos Exp $	*/
+/*	$NetBSD: pidfile.c,v 1.11 2015/01/22 19:04:28 christos Exp $	*/
 
 /*-
  * Copyright (c) 1999 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
 
 #include sys/cdefs.h
 #if defined(LIBC_SCCS)  !defined(lint)
-__RCSID($NetBSD: pidfile.c,v 1.10 2015/01/22 16:19:08 christos Exp $);
+__RCSID($NetBSD: pidfile.c,v 1.11 2015/01/22 19:04:28 christos Exp $);
 #endif
 
 #include sys/param.h
@@ -99,7 +99,7 @@ cleanup_old_pidfile(const char* path)
 }
 
 /* Constructs a name for a pidfile in the default location (/var/run).  If
  * 'basename' is NULL, uses the name of the current program for the name of
  * the pidfile.
  *
  * Returns a pointer to a dynamically-allocatd string containing the absolute
@@ -113,7 +113,7 @@ generate_varrun_path(const char *bname)
 		bname = getprogname();
 
 	/* _PATH_VARRUN includes trailing / */
-	if (asprintf(path, %s%s.pid, _PATH_VARRUN, basename) == -1)
+	if (asprintf(path, %s%s.pid, _PATH_VARRUN, bname) == -1)
 		return NULL;
 	return path;
 }
@@ -99,7 +99,7 @@ cleanup_old_pidfile(const char* path)
 
 /* Constructs a name for a pidfile in the default location (/var/run).  If
- * 'basename' is NULL, uses the name of the current program for the name of
+ * 'bname' is NULL, uses the name of the current program for the name of
  * the pidfile.
  *



CVS commit: src/lib/libutil

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 22 19:04:28 UTC 2015

Modified Files:
src/lib/libutil: pidfile.c

Log Message:
s/basename/bname/


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/lib/libutil/pidfile.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/etc

2015-01-22 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Thu Jan 22 19:50:21 UTC 2015

Modified Files:
src/etc/defaults: rc.conf
src/etc/rc.d: wpa_supplicant

Log Message:
It doesn't make sense to start wpa_supplicant from an rc.d script without
the -B flag, so always prepend it to $rc_flags.


To generate a diff of this commit:
cvs rdiff -u -r1.128 -r1.129 src/etc/defaults/rc.conf
cvs rdiff -u -r1.5 -r1.6 src/etc/rc.d/wpa_supplicant

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/usr.bin/config

2015-01-22 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 22 20:01:22 UTC 2015

Modified Files:
src/usr.bin/config: main.c mkheaders.c

Log Message:
appease gcc-4.5.4


To generate a diff of this commit:
cvs rdiff -u -r1.73 -r1.74 src/usr.bin/config/main.c
cvs rdiff -u -r1.25 -r1.26 src/usr.bin/config/mkheaders.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/include/cpu.h
diff -u src/sys/arch/powerpc/include/cpu.h:1.100 

CVS commit: src/sys/arch

2015-01-22 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Fri Jan 23 07:27:06 UTC 2015

Modified Files:
src/sys/arch/evbppc/mpc85xx: machdep.c
src/sys/arch/powerpc/booke: booke_machdep.c e500_intr.c
src/sys/arch/powerpc/include: cpu.h db_machdep.h
src/sys/arch/powerpc/include/booke: intr.h
src/sys/arch/powerpc/pic: ipi.c ipivar.h
src/sys/arch/powerpc/powerpc: db_interface.c powerpc_machdep.c

Log Message:
ddb MP support


To generate a diff of this commit:
cvs rdiff -u -r1.39 -r1.40 src/sys/arch/evbppc/mpc85xx/machdep.c
cvs rdiff -u -r1.22 -r1.23 src/sys/arch/powerpc/booke/booke_machdep.c
cvs rdiff -u -r1.30 -r1.31 src/sys/arch/powerpc/booke/e500_intr.c
cvs rdiff -u -r1.100 -r1.101 src/sys/arch/powerpc/include/cpu.h
cvs rdiff -u -r1.24 -r1.25 src/sys/arch/powerpc/include/db_machdep.h
cvs rdiff -u -r1.8 -r1.9 src/sys/arch/powerpc/include/booke/intr.h
cvs rdiff -u -r1.11 -r1.12 src/sys/arch/powerpc/pic/ipi.c
cvs rdiff -u -r1.7 -r1.8 src/sys/arch/powerpc/pic/ipivar.h
cvs rdiff -u -r1.52 -r1.53 src/sys/arch/powerpc/powerpc/db_interface.c
cvs rdiff -u -r1.70 -r1.71 src/sys/arch/powerpc/powerpc/powerpc_machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/powerpc/booke

2015-01-22 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Fri Jan 23 06:52:55 UTC 2015

Modified Files:
src/sys/arch/powerpc/booke: e500_tlb.c

Log Message:
- Use tlbivax instruction for TLB update/invalidate when MULTIPROCESSOR is
  defined. Because TLB entry operation is not notified to another CPU.
- When TLB1 is updated, send IPI_TLB1SYNC to another CPU.


To generate a diff of this commit:
cvs rdiff -u -r1.15 -r1.16 src/sys/arch/powerpc/booke/e500_tlb.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.